@@ -148,7 +148,11 @@ class ListLabor:
 
         result = []
         for elm in daily_list:
-            annofab_project_id = job_id_annofab_project_id_dict[elm.job_id]
+            annofab_project_id = job_id_annofab_project_id_dict.get(elm.job_id)
+            if annofab_project_id is None:
+                # annofabプロジェクトに紐付いていないジョブの場合に通る
+                continue
+
             annofab_account_id = user_id_annofab_account_id_dict[elm.user_id]
             result.append(
                 AnnofabLabor(
@@ -184,8 +188,6 @@ def visualize_statistics(temp_dir: Path, args):
         "annofabcli",
         "statistics",
         "visualize",
-        "--output_dir",
-        str(args.output_dir),
         "--labor_csv",
         str(annofab_labor_csv),
     ]
@@ -194,40 +196,22 @@ def visualize_statistics(temp_dir: Path, args):
         command.extend(["--project_id"] + annofab_project_id_list)
     elif job_id_list is not None:
         job_id_annofab_project_id_dict = main_obj.get_job_id_annofab_project_id_dict_from_job_id(job_id_list)
+        if len(job_id_annofab_project_id_dict) == 0:
+            logger.error(f"AnnoFabプロジェクトに紐づくジョブが0件なので、終了します。")
+            return
         command.extend(["--project_id"] + list(job_id_annofab_project_id_dict.values()))
 
-    if args.user_id is not None:
-        command.extend(["--user_id", args.user_id])
-
     if args.start_date is not None:
         command.extend(["--start_date", args.start_date])
 
     if args.end_date is not None:
         command.extend(["--end_date", args.end_date])
 
-    if args.task_id is not None:
-        command.extend(["--task_id", args.task_id])
+    if args.output_dir is not None:
+        command.extend(["--output_dir", str(args.output_dir)])
 
-    if args.task_query is not None:
-        command.extend(["--task_query", args.task_query])
-
-    if args.not_update:
-        command.append("--not_update")
-
-    if args.latest:
-        command.append("--latest")
-
-    if args.get_task_histories_one_of_each:
-        command.append("--get_task_histories_one_of_each")
-
-    if args.minimal:
-        command.append("--minimal")
-
-    if args.merge:
-        command.append("--merge")
-
-    if args.parallelism is not None:
-        command.extend(["--parallelism", str(args.parallelism)])
+    if args.annofabcli_options is not None:
+        command.extend(args.annofabcli_options)
 
     str_command = " ".join(command)
     logger.debug(f"run command: {str_command}")
@@ -255,78 +239,19 @@ def parse_args(parser: argparse.ArgumentParser):
     job_id_group.add_argument("-j", "--job_id", type=str, nargs="+", help="絞り込み対象のジョブID")
     job_id_group.add_argument("-af_p", "--annofab_project_id", type=str, nargs="+", help="絞り込み対象のAnnoFabのプロジェクトID")
 
+    parser.add_argument("-o", "--output_dir", type=Path, required=True, help="出力先ディレクトリ")
+
     parser.add_argument("--start_date", type=str, required=False, help="集計開始日(YYYY-mm-dd)")
     parser.add_argument("--end_date", type=str, required=False, help="集計終了日(YYYY-mm-dd)")
 
     parser.add_argument("--temp_dir", type=Path, required=False, help="テンポラリディレクトリ")
 
-    # annofabcli statistics visualizeコマンドに渡す引数
-    parser.add_argument("-o", "--output_dir", type=Path, required=True, help="[annofabcli] 出力先ディレクトリのパスを指定してください。")
-
+    # 残りの引数は `annofabcli statistics visualize`コマンドにそのまま渡す
     parser.add_argument(
-        "-u",
-        "--user_id",
-        nargs="+",
-        help=(
-            "[annofabcli] メンバごとの統計グラフに表示するユーザのuser_idを指定してください。"
-            "指定しない場合は、上位20人が表示されます。\n"
-            "``file://`` を先頭に付けると、一覧が記載されたファイルを指定できます。"
-        ),
-    )
-
-    parser.add_argument(
-        "-t",
-        "--task_id",
+        "--annofabcli_options",
+        nargs=argparse.REMAINDER,
         type=str,
-        required=False,
-        nargs="+",
-        help="[annofabcli] 集計対象のタスクのtask_idを指定します。\n" + "``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
-    )
-
-    parser.add_argument(
-        "-tq",
-        "--task_query",
-        type=str,
-        help="[annofabcli] タスクの検索クエリをJSON形式で指定します。指定しない場合はすべてのタスクを取得します。\n"
-        "``file://`` を先頭に付けると、JSON形式のファイルを指定できます。"
-        "クエリのキーは、task_id, phase, phase_stage, status のみです。",
-    )
-
-    parser.add_argument(
-        "--not_update",
-        action="store_true",
-        help="[annofabcli] 作業ディレクトリ内のファイルを参照して、統計情報を出力します。" "AnnoFab Web APIへのアクセスを最小限にします。",
-    )
-
-    parser.add_argument(
-        "--latest",
-        action="store_true",
-        help="[annofabcli] 統計情報の元になるファイル（アノテーションzipなど）の最新版を参照します。このオプションを指定すると、各ファイルを更新するのに5分以上待ちます。\n"
-        "ただしWebAPIの都合上、 'タスク履歴全件ファイル' は最新版を参照できません。タスク履歴の最新版を参照する場合は ``--get_task_histories_one_of_each`` を指定してください。",
-    )
-
-    parser.add_argument(
-        "--get_task_histories_one_of_each",
-        action="store_true",
-        help="[annofabcli] タスク履歴を1個ずつ取得して、タスク履歴の最新版を参照します。タスクの数だけWebAPIを実行するので、処理時間が長くなります。",
-    )
-
-    parser.add_argument(
-        "--minimal",
-        action="store_true",
-        help="[annofabcli] 必要最小限のファイルを出力します。",
-    )
-
-    parser.add_argument(
-        "--merge",
-        action="store_true",
-        help="[annofabcli] 指定した場合、複数のproject_idを指定したときに、マージした統計情報も出力します。ディレクトリ名は ``merge`` です。",
-    )
-
-    parser.add_argument(
-        "--parallelism",
-        type=int,
-        help="[annofabcli] 並列度。 ``--project_id`` に複数のproject_idを指定したときのみ有効なオプションです。" "指定しない場合は、逐次的に処理します。",
+        help="``annofabcli_options`` 以降のオプションを、 ``annofabcli statistics visualize`` コマンドにそのまま渡します。",
     )
 
     parser.set_defaults(subcommand_func=main)
